@@ -84,8 +84,9 @@ def get_synchronization_tasks(object_name):
                   'depend': (Tasks.success() & ~AllTasks.has_any("not_use_search") &
                              (~AllTasks.success_one_of("check_current_binhost") |
                              AllTasks.success_all("sync_reps"))),
-                  'condition': lambda Get: Get('update.cl_update_use_migration_host') == 'off' and
-                                           not Get("update.cl_update_binhost_choice")
+                  'condition': lambda Get: Get('update.cl_update_use_migration_host') == 'off'# or
+                                        #(not Get("update.cl_update_binhost_recheck_set") and (not Get("update.cl_update_binhost_choice") != 'auto'
+                                         #or not Get("update.cl_update_binhost_choice")))
                  },
                  {'name': 'interrupt_on_no_leveled_binhost',
                   'method': Object("interrupt_on_no_leveled_binhost()"),
@@ -129,7 +130,9 @@ def get_synchronization_tasks(object_name):
                  },
                  {'name': 'sync_reps:update_local_info_binhost',
                   'method': Object('update_local_info_binhost()'),
-                  'condition': lambda Get: not Get("update.cl_update_binhost_choice")
+                  'condition': lambda Get: Get("update.cl_update_binhost_choice") == 'auto'
+                                           or not Get("update.cl_update_binhost_choice")
+                                           or Get("update.cl_update_binhost_recheck_set")
                  },
                  {'name': 'sync_reps:update_binhost_list',
                   'essential': False,
