@@ -1732,17 +1732,25 @@ class VariableClUpdateBinhostChoice(Variable):
         self.label = _("Packages mirror")
         self.help = _("Url to download binary packages from")
 
+    def get(self):
+        if not self.value:
+            if self.GetBool("cl_update_binhost_set") and self.Get("cl_update_binhost"):
+                return self.Get("cl_update_binhost")
+        return self.value
+
     def choice(self):
-        return self.Get("cl_update_binhost_list") + ['auto']
+        if self.GetBool("cl_update_binhost_set") and self.Get("cl_update_binhost"):
+            if self.Get("cl_update_binhost") not in self.Get("cl_update_binhost_list"):
+                return ['auto'] + [self.Get("cl_update_binhost")] + self.Get("cl_update_binhost_list")
+        return ['auto'] + self.Get("cl_update_binhost_list")
 
 
 class VariableClUpdateNewBinhost(Variable):
     def get(self):
         if self.Get('cl_update_binhost_choice'):
             binhost = self.Get('cl_update_binhost_choice')
-            if binhost == 'auto':
-                return self.Get('cl_update_binhost')
-            return binhost
+            if binhost != 'auto':
+                return binhost
         return self.Get('cl_update_binhost')
 
 
@@ -1839,7 +1847,9 @@ class VariableClUpdatePortageBinhost(ReadonlyVariable):
     #value_format = "{update.cl_update_binhost}/grp/{os_arch_machine}"
 
     def get(self):
-        if self.Get('update.cl_update_binhost_choice'):
+        if not self.Get('update.cl_update_binhost_recheck_set') \
+                and self.Get('update.cl_update_binhost_choice') \
+                and self.Get('update.cl_update_binhost_choice') != 'auto':
             return f"{self.Get('update.cl_update_binhost_choice')}/grp/{self.Get('os_arch_machine')}"
         return f"{self.Get('update.cl_update_binhost')}/grp/{self.Get('os_arch_machine')}"
 
